pub struct ZwpConfinedPointerV1 { /* private fields */ }Expand description
confined pointer object
The wp_confined_pointer interface represents a confined pointer state.
This object will send the event ‘confined’ when the confinement is activated. Whenever the confinement is activated, it is guaranteed that the surface the pointer is confined to will already have received pointer focus and that the pointer will be within the region passed to the request creating this object. It is up to the compositor to decide whether this requires some user interaction and if the pointer will warp to within the passed region if outside.
To unconfine the pointer, send the destroy request. This will also destroy the wp_confined_pointer object.
If the compositor decides to unconfine the pointer the unconfined event is sent. The wp_confined_pointer object is at this point defunct and should be destroyed.
See also the Event enum for this interface.
Implementations
Sourceimpl ZwpConfinedPointerV1
impl ZwpConfinedPointerV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the confined pointer object
Destroy the confined pointer object. If applicable, the compositor will unconfine the pointer.
Sourcepub fn set_region(&self, region: Option<&WlRegion>)
pub fn set_region(&self, region: Option<&WlRegion>)
set a new confine region
Set a new region used to confine the pointer.
The new confine region is double-buffered, see wl_surface.commit.
If the confinement is active when the new confinement region is applied and the pointer ends up outside of newly applied region, the pointer may warped to a position within the new confinement region. If warped, a wl_pointer.motion event will be emitted, but no wp_relative_pointer.relative_motion event.
The compositor may also, instead of using the new region, unconfine the pointer.
For details about the confine region, see wp_confined_pointer.